View source: R/apply_identifications.R
| apply_identifications | R Documentation |
Applies identification constraints to factors and loadings.
apply_identifications(factors, loadings)
factors |
A numeric matrix with the current estimate of all factors (T × total factors). |
loadings |
A numeric matrix with the current estimate of all factor loadings (total factors x N). |
A list containing:
A matrix containing identified factors.
A matrix of identified factor loadings.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.