View source: R/compute_initial_factors.R
| compute_initial_factors | R Documentation |
Computes the initial set of global, middle-layer, and local factors using either PCA or CCA.
compute_initial_factors(
data,
num_vars,
num_obs,
num_blocks,
ranges,
r_list,
method
)
data |
A numeric matrix or data frame containing the time series data (T × N). |
num_vars |
Integer vector. Number of variables in each block. |
num_obs |
Integer. Number of time observations (T). |
num_blocks |
Integer. Number of blocks. |
ranges |
A list of vectors with the column indices for each block. |
r_list |
A named list specifying the number of factors to extract for each node (from |
method |
Integer. Method for factor extraction: |
A list with two elements:
Matrix of all initial factors (T × total number of factors).
Named list of factors for each node in the hierarchy.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.