View source: R/compute_loadings.R
| compute_loadings | R Documentation |
Computes the full loadings matrix for the Multi-Level Dynamic Factor Model.
compute_loadings(data, num_blocks, ranges, r_list, factor_list, loadings_list)
data |
A numeric matrix or data frame containing the time series data (T × N). |
num_blocks |
Integer. Number of blocks. |
ranges |
A list of vectors with the column indices for each block. |
r_list |
A named list specifying the number of factors to extract for each node (from |
factor_list |
A named list of factors extracted at each node (from |
loadings_list |
A named list to which updated loadings will be appended for each node. |
A list with:
A numeric matrix (total factors × total variables) with estimated loadings.
An updated named list of loadings for each node.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.