fars_map_state: fars_map_state function

Description Usage Arguments Value Examples

View source: R/fars_functions.R

Description

this is a function that creates a map of a specified state at a specified year

Usage

1
fars_map_state(state.num, year)

Arguments

state.num

A number indicating a state of interest

year

A number of year of interest

Value

this function returns a map. If state number does not exist, a warning message would print. If no accidents in the state in the year, no plot would be generated and a message would print.

Examples

1
## Not run: fars_map_state(1,2013)

hsm-stephanie/fars documentation built on Jan. 7, 2020, 12:25 a.m.