fars_read: Title: fars_functions fars_read function

Description Usage Arguments Value Examples

View source: R/fars_functions.R

Description

This is a function that read in existing data files with readr package without showing progress or printing any messages

Usage

1
fars_read(filename)

Arguments

filename

A character string giving the file name and path

Value

this function returns a data frame. If file name or path does not exist, it will give a warning message.

Examples

1
2
3
4
## Not run: fars_read("accident_2013.csv")
fars_read("C:\mydata\accident_2013.csv")
fars_read("http:\\abc.org\accident_2013.csv")
## End(Not run)

hsm-stephanie/fars documentation built on Jan. 7, 2020, 12:25 a.m.