fars_read_years: fars_read_years function

Description Usage Arguments Value Examples

View source: R/fars_functions.R

Description

this is a function that reads in complied file names with specified years of interest and then returns data by month of the year of interest

Usage

1

Arguments

years

A list of numbers specifying the years of interest

Value

this function returns a data frame. If the year of interest doesn't exist, it will print a warning message.

Examples

1
## Not run: fars_read_years(2013)

hsm-stephanie/fars documentation built on Jan. 7, 2020, 12:25 a.m.