fars_summarize_years: fars_summarize_years function

Description Usage Arguments Value Examples

View source: R/fars_functions.R

Description

this is a function that combines data of different years and then creates a summary table of total number of observations by year and month

Usage

1

Arguments

years

A list of numbers specifying the years of interest

Value

this function returns a summary table of total number of observations by year and month

Examples

1
## Not run: fars_summarize_years(2013)

hsm-stephanie/fars documentation built on Jan. 7, 2020, 12:25 a.m.