fitted.fars: Fitted Values for 'fars' Object

View source: R/fars_methods.R

fitted.farsR Documentation

Fitted Values for fars Object

Description

Returns a matrix of fitted values from all quantile regressions stored in a fars object.

Usage

## S3 method for class 'fars'
fitted(object, ...)

Arguments

object

An object of class fars.

...

Additional arguments (ignored).

Value

A numeric matrix with one column per quantile level and as many rows as observations used in the fit.

Examples

fars_result <- compute_fars(dep_variable = rnorm(100), 
                            factors = matrix(rnorm(100 * 3), ncol = 3))
fitted(fars_result)


FARS documentation built on Feb. 17, 2026, 5:06 p.m.