get_level_factors: Extract Factors at a Given Hierarchical Level

View source: R/get_level_factors.R

get_level_factorsR Documentation

Extract Factors at a Given Hierarchical Level

Description

Retrieves all factors from a given level of the hierarchical structure that include the specified combination of blocks.

Usage

get_level_factors(factor_list, combination, level)

Arguments

factor_list

A named list of factors for each node (from build_factor_structure).

combination

Integer vector. Indices of the blocks involved in the current node.

level

Integer. The hierarchical level (i.e., the number of blocks involved).

Value

A matrix of concatenated factors matching the given level and combination, or NULL if no match is found.


FARS documentation built on Feb. 17, 2026, 5:06 p.m.