get_quantile_levels.fars: Extract Quantile Levels from a 'fars' Object

View source: R/fars_methods.R

get_quantile_levels.farsR Documentation

Extract Quantile Levels from a fars Object

Description

Returns the quantile levels from an object of class fars.

Usage

## S3 method for class 'fars'
get_quantile_levels(x, ...)

Arguments

x

An object of class fars, typically the result of a computation such as compute_fars.

...

Additional arguments (ignored).

Value

A vector of quantile levels stored within the fars object.

Examples

fars_result <- compute_fars(dep_variable = rnorm(100), 
                            factors = matrix(rnorm(100 * 3), ncol = 3))
get_quantile_levels(fars_result)  


FARS documentation built on Feb. 17, 2026, 5:06 p.m.