get_rq_model.fars: Extract a Specific 'rq' Object from a 'fars' Object

View source: R/fars_methods.R

get_rq_model.farsR Documentation

Extract a Specific rq Object from a fars Object

Description

Returns the rq fit stored inside a fars object at the requested quantile.

Usage

## S3 method for class 'fars'
get_rq_model(x, tau, ...)

Arguments

x

An object of class mldfm_subsample.

tau

Numeric scalar in (0, 1) indicating the desired quantile.

...

Additional arguments (ignored).

Value

A single rq object.

Examples

fars_result <- compute_fars(dep_variable = rnorm(100), 
                            factors = matrix(rnorm(100 * 3), ncol = 3))
get_rq_model(fars_result, tau = 0.05)  


FARS documentation built on Feb. 17, 2026, 5:06 p.m.