make_filename: make_filename function

Description Usage Arguments Value Examples

View source: R/fars_functions.R

Description

this is a function that compiles a character string of filename with specified year as input

Usage

1

Arguments

year

A number specifying the year of interest

Value

this function returns a character string of filename starting with "accident_" and then the integer year and then ending with ".csv.bz2"

Examples

1
2
#use examples instead of example then no warning of example doesn't exist
## Not run: make_filename(2013)

hsm-stephanie/fars documentation built on Jan. 7, 2020, 12:25 a.m.