View source: R/multiple_blocks.R
| multiple_blocks | R Documentation |
Estimates a Multi-Level Dynamic Factor Model (MLDFM) using Sequential Least Squares Estimation approach
multiple_blocks(
data,
global,
local,
middle_layer,
block_ind,
tol,
max_iter,
method
)
data |
A numeric matrix or data frame containing the time series data (T × N). |
global |
Integer. Number of global factors extracted from the entire dataset. |
local |
Integer vector of length |
middle_layer |
Named list. Each name is a string specifying a group of blocks (e.g., |
block_ind |
Integer vector. End column indices for each block. Must be of length |
tol |
Numeric. The tolerance level for the residual sum of squares (RSS) minimization process. Used as a convergence criterion. |
max_iter |
Integer. The maximum number of iterations allowed for the RSS minimization process. |
method |
Integer. Method used to initialize the factors: |
A list with elements:
Matrix of estimated factors.
Matrix of factor loadings.
Matrix of residuals.
Matrix of fitted values.
Initialization method used (CCA or PCA).
Number of iterations before convergence.
List of estimated factors for each node.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.