| plot.fars | R Documentation |
fars ObjectGenerates a line plot of the estimated quantiles from a fars object.
If newdata is NULL, the function plots in-sample fitted quantiles; otherwise,
it plots predictions computed on newdata. The x-axis can be indexed by a provided
dates vector; if missing, an integer index is used.
## S3 method for class 'fars'
plot(x, newdata = NULL, dates = NULL, ...)
x |
An object of class |
newdata |
Optional matrix or data frame with one column for the lagged dependent variable
and |
dates |
Optional vector of dates (as |
... |
Additional arguments (ignored). |
Invisibly returns a ggplot object.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.