| plot_factors.mldfm | R Documentation |
mldfm ObjectDisplays time series plots of the estimated factors with 95% confidence bands.
plot_factors.mldfm(x, dates = NULL, flip = NULL, fpr = FALSE, ...)
x |
An object of class |
dates |
Optional vector of dates. If NULL, uses 1:n as default. |
flip |
Optional vector of length equal to the number of factors. Set 1 to flip sign for a specific factor (and related loadings); 0 to leave unchanged. |
fpr |
Logical. If |
... |
Additional arguments (ignored). |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.