plot_loadings.mldfm: Plot Loadings from 'mldfm' Object

View source: R/plot.R

plot_loadings.mldfmR Documentation

Plot Loadings from mldfm Object

Description

Displays bar plots of the estimated factor loadings with 95% confidence intervals.

Usage

plot_loadings.mldfm(x, var_names = NULL, flip = NULL, ...)

Arguments

x

An object of class mldfm.

var_names

Optional vector of variable names. If NULL, default names are used.

flip

Optional vector of length equal to the number of factors. Set 1 to flip sign for a specific factor (and related loadings); 0 to leave unchanged.

...

Additional arguments (ignored).


FARS documentation built on Feb. 17, 2026, 5:06 p.m.