| residuals.fars | R Documentation |
fars ObjectReturns a matrix of residuals from all quantile regressions stored in a fars object.
## S3 method for class 'fars'
residuals(object, ...)
object |
An object of class |
... |
Additional arguments (ignored). |
A numeric matrix with one column per quantile level and as many rows as observations used in the fit.
fars_result <- compute_fars(dep_variable = rnorm(100),
factors = matrix(rnorm(100 * 3), ncol = 3))
residuals(fars_result)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.