| single_block | R Documentation |
Estimates a Dynamic Factor Model (DFM) when only one block is present, using Principal Component Analysis (PCA).
single_block(data, r)
data |
A numeric matrix or data frame containing the time series data (T × N). |
r |
Integer. Number of factors to extract. |
A list with elements:
Matrix of estimated factors.
Matrix of factor loadings.
Matrix of residuals.
Matrix of fitted values.
Method used for factor extraction ("PCA").
Number of iterations before convergence (always 0 for single block).
List of estimated factors for each node.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.