View source: R/update_factor_list.R
| update_factor_list | R Documentation |
Updates the list of factors at each hierarchical node by slicing from a matrix containing all final factors.
update_factor_list(factor_list, final_factors, r_list)
factor_list |
A named list of factors for each node in the hierarchy. |
final_factors |
A numeric matrix containing all factors (T × total number of factors). |
r_list |
A named list specifying the number of factors for each node (from |
An updated named list of factors.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.