View source: R/build_factor_structure.R
| build_factor_structure | R Documentation |
Constructs a named list defining the factor structure across global, middle-layer, and local levels,
build_factor_structure(
global = 1,
local = NULL,
middle_layer = NULL,
num_blocks = NULL
)
global |
Integer. Number of global factors extracted from the entire dataset. |
local |
Integer vector of length |
middle_layer |
Named list. Each name is a string specifying a group of blocks (e.g., |
num_blocks |
Integer. Number of blocks into which the data is divided. |
A named list where each name corresponds to a block or group of blocks (e.g., "1", "1-3"), and the value is the number of factors associated with that node.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.