| coef.fars | R Documentation |
fars ObjectReturns a matrix of estimated coefficients from all quantile regressions stored in a fars object.
## S3 method for class 'fars'
coef(object, ...)
object |
An object of class |
... |
Additional arguments (ignored). |
A numeric matrix with one column per quantile level and one row per coefficient.
Column names correspond to quantile levels (e.g. 0.05, 0.25, ...),
and row names to coefficient names.
fars_result <- compute_fars(dep_variable = rnorm(100),
factors = matrix(rnorm(100 * 3), ncol = 3))
coef(fars_result)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.