| compute_fars | R Documentation |
Performs quantile regressions of a dependent variable on factors estimates.
compute_fars(dep_variable, factors, h = 1, edge = 0.05)
dep_variable |
Numeric vector of length T representing the dependent variable (e.g., GDP growth, inflation). |
factors |
Numeric matrix or data frame of dimension T x r, containing factor estimates. |
h |
Integer (>= 1). Lag order used in the regression (default = 1) |
edge |
Numeric value specifying the trimming amount applied to the outermost quantiles. Default is 0.05. |
An object of class fars, which is a list containing:
modelsList of five S3 quantreg::rq fitted objects named tau_0.xx.
hThe forecast horizon used.
levelsThe vector of quantile levels effectively estimated
(c(edge, 0.25, 0.50, 0.75, 1 - edge)).
.
periodsInteger. The number of fitted periods
n_factorsInteger. The number of factors included in the regression.
callThe matched function call.
set.seed(123)
T <- 100; r <- 3
Y <- rnorm(T)
F <- matrix(rnorm(T * r), T, r)
fars_result <- compute_fars(dep_variable = Y, factors = F, h = 1, edge = 0.05)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.