Description Usage Arguments Value Examples
View source: R/fars_functions.R
this is a function that creates a map of a specified state at a specified year
1 | fars_map_state(state.num, year)
|
state.num |
A number indicating a state of interest |
year |
A number of year of interest |
this function returns a map. If state number does not exist, a warning message would print. If no accidents in the state in the year, no plot would be generated and a message would print.
1 | ## Not run: fars_map_state(1,2013)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.