fars_map_state: fars_map_state

Description Usage Arguments Value Examples

View source: R/fars_function.R

Description

This function provide a plot with a state map including the accidents location by year.

Usage

1
fars_map_state(state.num, year)

Arguments

state.num

An Integer with the State Code.

year

An integer, a numeric or string of the year.

Value

None.

Examples

1
2
3
4
## Not run: 
fars_map_state(35, 2013)

## End(Not run)

hsuzero/fars documentation built on Dec. 20, 2021, 4:51 p.m.