Description Usage Arguments Value Examples
View source: R/fars_function.R
This function provide a plot with a state map including the accidents location by year.
1 | fars_map_state(state.num, year)
|
state.num |
An Integer with the State Code. |
year |
An integer, a numeric or string of the year. |
None.
1 2 3 4 | ## Not run:
fars_map_state(35, 2013)
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.