fars_map_state: Creates a map of number of fatalities for a given state and...

Description Usage Arguments Value Examples

Description

This function uses state number and year as input and if fatality data exists, it puts this data on a map

Usage

1
fars_map_state(state.num, year)

Arguments

state.num

Identifier for state number

year

a single year for which to plot the data

Value

This function returns a map of fatalities for a given state and year

Examples

1
fars_map_state(1, 2015)

pchhina/fars documentation built on May 5, 2019, 3:54 p.m.