Description Usage Arguments Value Examples
This function uses state number and year as input and if fatality data exists, it puts this data on a map
1 | fars_map_state(state.num, year)
|
state.num |
Identifier for state number |
year |
a single year for which to plot the data |
This function returns a map of fatalities for a given state and year
1 | fars_map_state(1, 2015)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.