Description Usage Arguments Value Examples
View source: R/fars_functions.R
This function reads data in CSV format into R. First, it checks whether the file already exists in the working directory. If the file does not exist, you get an error message. Second, if the CSV file exists, it is read into R. Third, the data are converted to a tibble.
1 | fars_read(filename)
|
filename |
A string with the full name of a file in CSV format. This function returns an error, if the file does not exist in the directory. |
This function returns a data frame in tibble format.
1 2 3 4 5 6 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.