fars_read: This is a assignment to Coursera Building R Packages week2....

Description Usage Arguments Value Examples

View source: R/fars_function.R

Description

The functions will be using data from the US National Highway Traffic Safety Administration's Fatality Analysis Reporting System, which is a nationwide census providing the American public yearly data regarding fatal injuries suffered in motor vehicle traffic crashes.

Usage

1
fars_read(filename)

Arguments

filename

A character string with the filename to read.

Value

This function returns a data frame from csv file, or an error with wrong filename.

Examples

1
fars_read(filename = 'accident_2013.csv.bz2')

hsuzero/fars documentation built on Dec. 20, 2021, 4:51 p.m.