Description Usage Arguments Value Examples
View source: R/fars_function.R
The functions will be using data from the US National Highway Traffic Safety Administration's Fatality Analysis Reporting System, which is a nationwide census providing the American public yearly data regarding fatal injuries suffered in motor vehicle traffic crashes.
1 | fars_read(filename)
|
filename |
A character string with the filename to read. |
This function returns a data frame from csv file, or an error with wrong filename.
1 | fars_read(filename = 'accident_2013.csv.bz2')
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.