Description Usage Arguments Value Examples
View source: R/fars_functions.R
this is a function that reads in complied file names with specified years of interest and then returns data by month of the year of interest
1 | fars_read_years(years)
|
years |
A list of numbers specifying the years of interest |
this function returns a data frame. If the year of interest doesn't exist, it will print a warning message.
1 | ## Not run: fars_read_years(2013)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.