Description Usage Arguments Value Examples
View source: R/fars_function.R
This function takes a vector of years and produces a list of tibbles, where each tibble is that year's FARS file year and MONTH observations.
1 | fars_read_years(years)
|
years |
Vector of years' FARS files to open. |
A data.frame including entries in data by month, or NULL if the
year is not valid.
1 | fars_read_years(years = c(2014, 2015))
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.