fars_read_years: Reads data from a file for each year, subsets month and year...

Description Usage Arguments Value Examples

Description

This function reads in a vector of years. For each year, it makes a filename, reads the data from that file, adds a year column to the data, selects, month and year variables, and finally stores that into an element of list.

Usage

1

Arguments

years

a single year or a vector containing multiple years

Value

This function returns a list containing month and year from each years data

Examples

1

pchhina/fars documentation built on May 5, 2019, 3:54 p.m.