Description Usage Arguments Value Examples
This function reads in a vector of years. For each year, it makes a filename, reads the data from that file, adds a year column to the data, selects, month and year variables, and finally stores that into an element of list.
1 | fars_read_years(years)
|
years |
a single year or a vector containing multiple years |
This function returns a list containing month and year from each years data
1 | fars_read_years(2012)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.