Description Usage Arguments Value Examples
View source: R/fars_functions.R
this is a function that combines data of different years and then creates a summary table of total number of observations by year and month
1 | fars_summarize_years(years)
|
years |
A list of numbers specifying the years of interest |
this function returns a summary table of total number of observations by year and month
1 | ## Not run: fars_summarize_years(2013)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.