fars_summarize_years: Creates a table of number of observations for each month and...

Description Usage Arguments Value Examples

Description

This function uses the list created by fars_read_years, calculates the number of observations for each month and year pair and generates a tabular output of this data.

Usage

1

Arguments

years

a single year or a vector containing multiple years

Value

This function returns a table of number of observations for each month and year

Examples

1
2
library(magrittr)
fars_summarize_years(2013)

pchhina/fars documentation built on May 5, 2019, 3:54 p.m.