Description Usage Arguments Value Examples
This function uses the list created by fars_read_years, calculates the number of observations for each month and year pair and generates a tabular output of this data.
1 | fars_summarize_years(years)
|
years |
a single year or a vector containing multiple years |
This function returns a table of number of observations for each month and year
1 2 | library(magrittr)
fars_summarize_years(2013)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.