View source: R/get_level_factors.R
| get_level_factors | R Documentation |
Retrieves all factors from a given level of the hierarchical structure that include the specified combination of blocks.
get_level_factors(factor_list, combination, level)
factor_list |
A named list of factors for each node (from |
combination |
Integer vector. Indices of the blocks involved in the current node. |
level |
Integer. The hierarchical level (i.e., the number of blocks involved). |
A matrix of concatenated factors matching the given level and combination, or NULL if no match is found.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.