| get_quantile_levels.fars | R Documentation |
fars ObjectReturns the quantile levels from an object of class fars.
## S3 method for class 'fars'
get_quantile_levels(x, ...)
x |
An object of class |
... |
Additional arguments (ignored). |
A vector of quantile levels stored within the fars object.
fars_result <- compute_fars(dep_variable = rnorm(100),
factors = matrix(rnorm(100 * 3), ncol = 3))
get_quantile_levels(fars_result)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.