Description Usage Arguments Value Examples
View source: R/fars_functions.R
this is a function that compiles a character string of filename with specified year as input
1 | make_filename(year)
|
year |
A number specifying the year of interest |
this function returns a character string of filename starting with "accident_" and then the integer year and then ending with ".csv.bz2"
1 2 | #use examples instead of example then no warning of example doesn't exist
## Not run: make_filename(2013)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.