make_filename: make_filename

Description Usage Arguments Value Examples

View source: R/fars_function.R

Description

This function make csv filenames related to the argument year. This function doesn't check the file available or not.

Usage

1

Arguments

year

An integer, a numeric or string of the year.

Value

this function returns a string that is the proper FARS data filename for the given year.

Examples

1
make_filename(year = '2013')

hsuzero/fars documentation built on Dec. 20, 2021, 4:51 p.m.