Description Usage Arguments Value Examples
View source: R/fars_function.R
This function make csv filenames related to the argument year.
This function doesn't check the file available or not.
1 | make_filename(year)
|
year |
An integer, a numeric or string of the year. |
this function returns a string that is the proper FARS data filename for the given year.
1 | make_filename(year = '2013')
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.