make_filename: Creates a filename from year input

Description Usage Arguments Value Examples

Description

This function takes year as input and creates a filename using that year.

Usage

1

Arguments

year

year from which to create the name of the file

Value

This function returns name of the file containing year.

Examples

1

pchhina/fars documentation built on May 5, 2019, 3:54 p.m.