Description Usage Arguments Value Examples
This function takes year as input and creates a filename using that year.
1 | make_filename(year)
|
year |
year from which to create the name of the file |
This function returns name of the file containing year.
1 | make_filename(1980)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.