| plot.mldfm | R Documentation |
Dispatches to specific plot functions for factors, loadings, or residuals.
## S3 method for class 'mldfm'
plot(
x,
which = "factors",
dates = NULL,
var_names = NULL,
flip = NULL,
fpr = FALSE,
...
)
x |
An object of class |
which |
What to plot: one of |
dates |
Optional vector of dates (as |
var_names |
Optional vector of variable names to label loadings and residual axis. |
flip |
Optional vector of length equal to the number of factors. Set 1 to flip sign for a specific factor (and related loadings); 0 to leave unchanged. |
fpr |
Logical. If |
... |
Additional arguments (ignored) |
No return value. Called for plots generation.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.