| plot_loadings.mldfm | R Documentation |
mldfm ObjectDisplays bar plots of the estimated factor loadings with 95% confidence intervals.
plot_loadings.mldfm(x, var_names = NULL, flip = NULL, ...)
x |
An object of class |
var_names |
Optional vector of variable names. If NULL, default names are used. |
flip |
Optional vector of length equal to the number of factors. Set 1 to flip sign for a specific factor (and related loadings); 0 to leave unchanged. |
... |
Additional arguments (ignored). |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.