| predict.fars | R Documentation |
fars ObjectComputes predictions from all quantile regressions in a fars object.
newdata must contain (in this order) the lagged dependent variable column
followed by the factor columns. Column names are generated internally as
LagY, F1, F2, ..., Fr.
## S3 method for class 'fars'
predict(object, newdata, ...)
object |
An object of class |
newdata |
A matrix or data frame with one column for the lagged dependent variable
and |
... |
Additional arguments (ignored). |
A numeric matrix with one column per quantile level and one row per observation in newdata.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.