Learn R Programming

FARS (version 0.8.0)

residuals.fars: Residuals for fars Object

Description

Returns a matrix of residuals from all quantile regressions stored in a fars object.

Usage

# S3 method for fars
residuals(object, ...)

Value

A numeric matrix with one column per quantile level and as many rows as observations used in the fit.

Arguments

object

An object of class fars.

...

Additional arguments (ignored).

Examples

Run this code
fars_result <- compute_fars(dep_variable = rnorm(100), 
                            factors = matrix(rnorm(100 * 3), ncol = 3))
residuals(fars_result)

Run the code above in your browser using DataLab